pub struct GroundDynamics {}Trait Implementations
Sourceimpl Clone for GroundDynamics
impl Clone for GroundDynamics
Sourcefn clone(&self) -> GroundDynamics
fn clone(&self) -> GroundDynamics
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Dynamics for GroundDynamics
impl Dynamics for GroundDynamics
type StateType = GroundAsset
Sourcetype HyperdualSize = Const<6>
type HyperdualSize = Const<6>
The state of the associated hyperdual state, almost always StateType + U1
Sourcefn eom(
&self,
_delta_t: f64,
_state_vec: &OVector<f64, <Self::StateType as State>::VecLength>,
state_ctx: &Self::StateType,
_almanac: Arc<Almanac>,
) -> Result<OVector<f64, <Self::StateType as State>::VecLength>, DynamicsError>
fn eom( &self, _delta_t: f64, _state_vec: &OVector<f64, <Self::StateType as State>::VecLength>, state_ctx: &Self::StateType, _almanac: Arc<Almanac>, ) -> Result<OVector<f64, <Self::StateType as State>::VecLength>, DynamicsError>
Defines the equations of motion for these dynamics, or a combination of provided dynamics.
The time delta_t is in seconds PAST the context epoch. The state vector is the state which
changes for every intermediate step of the integration. The state context is the state of
what is being propagated, it should allow rebuilding a new state context from the
provided state vector.
Sourcefn dual_eom(
&self,
_delta_t: f64,
osc: &Self::StateType,
_almanac: Arc<Almanac>,
) -> Result<(OVector<f64, <Self::StateType as State>::Size>, OMatrix<f64, <Self::StateType as State>::Size, <Self::StateType as State>::Size>), DynamicsError>
fn dual_eom( &self, _delta_t: f64, osc: &Self::StateType, _almanac: Arc<Almanac>, ) -> Result<(OVector<f64, <Self::StateType as State>::Size>, OMatrix<f64, <Self::StateType as State>::Size, <Self::StateType as State>::Size>), DynamicsError>
Defines the equations of motion for Dual numbers for these dynamics.
All dynamics need to allow for automatic differentiation. However, if differentiation is not supported,
then the dynamics should prevent initialization with a context which has an STM defined.
Sourcefn finally(
&self,
next_state: Self::StateType,
_almanac: Arc<Almanac>,
) -> Result<Self::StateType, DynamicsError>
fn finally( &self, next_state: Self::StateType, _almanac: Arc<Almanac>, ) -> Result<Self::StateType, DynamicsError>
Optionally performs some final changes after each successful integration of the equations of motion.
For example, this can be used to update the Guidance mode.
NOTE: This function is also called just prior to very first integration step in order to update the initial state if needed.